@@ -408,8 +408,8 @@ def main(handwriting_datasets_file):
     analyze_distance_betwee_strokes(raw_datasets)
 
     cfg = utils.get_project_configuration()
-    if 'data_analyzation_plugins' in cfg:
-        metrics = dam.get_metrics(cfg['data_analyzation_plugins'])
+    if 'data_analyzation_queue' in cfg:
+        metrics = dam.get_metrics(cfg['data_analyzation_queue'])
 
     for metric in metrics:
         logging.info("Start metric %s...", str(metric))
